@@ -13,7 +13,10 @@ import cdk8s_plus_17._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk8s-redis-sts", "0.0.5", __name__[0:-6], "cdk8s-redis-sts@0.0.5.jsii.tgz"
+    "@opencdk8s/cdk8s-redis-sts",
+    "0.0.6",
+    __name__[0:-6],
+    "cdk8s-redis-sts@0.0.6.jsii.tgz",
 )
 
 __all__ = [
